Class: Google::Apis::IdsV1::Endpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ids_v1/classes.rb,
lib/google/apis/ids_v1/representations.rb,
lib/google/apis/ids_v1/representations.rb

Overview

Endpoint describes a single IDS endpoint. It defines a forwarding rule to which packets can be sent for IDS inspection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Endpoint

Returns a new instance of Endpoint.



133
134
135
# File 'lib/google/apis/ids_v1/classes.rb', line 133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The create time timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


62
63
64
# File 'lib/google/apis/ids_v1/classes.rb', line 62

def create_time
  @create_time
end

#descriptionString

User-provided description of the endpoint Corresponds to the JSON property description

Returns:

  • (String)


67
68
69
# File 'lib/google/apis/ids_v1/classes.rb', line 67

def description
  @description
end

#endpoint_forwarding_ruleString

Output only. The fully qualified URL of the endpoint's ILB Forwarding Rule. Corresponds to the JSON property endpointForwardingRule

Returns:

  • (String)


72
73
74
# File 'lib/google/apis/ids_v1/classes.rb', line 72

def endpoint_forwarding_rule
  @endpoint_forwarding_rule
end

#endpoint_ipString

Output only. The IP address of the IDS Endpoint's ILB. Corresponds to the JSON property endpointIp

Returns:

  • (String)


77
78
79
# File 'lib/google/apis/ids_v1/classes.rb', line 77

def endpoint_ip
  @endpoint_ip
end

#labelsHash<String,String>

The labels of the endpoint. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


82
83
84
# File 'lib/google/apis/ids_v1/classes.rb', line 82

def labels
  @labels
end

#nameString

Output only. The name of the endpoint. Corresponds to the JSON property name

Returns:

  • (String)


87
88
89
# File 'lib/google/apis/ids_v1/classes.rb', line 87

def name
  @name
end

#networkString

Required. The fully qualified URL of the network to which the IDS Endpoint is attached. Corresponds to the JSON property network

Returns:

  • (String)


93
94
95
# File 'lib/google/apis/ids_v1/classes.rb', line 93

def network
  @network
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


98
99
100
# File 'lib/google/apis/ids_v1/classes.rb', line 98

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


104
105
106
# File 'lib/google/apis/ids_v1/classes.rb', line 104

def satisfies_pzs
  @satisfies_pzs
end

#severityString

Required. Lowest threat severity that this endpoint will alert on. Corresponds to the JSON property severity

Returns:

  • (String)


110
111
112
# File 'lib/google/apis/ids_v1/classes.rb', line 110

def severity
  @severity
end

#stateString

Output only. Current state of the endpoint. Corresponds to the JSON property state

Returns:

  • (String)


115
116
117
# File 'lib/google/apis/ids_v1/classes.rb', line 115

def state
  @state
end

#threat_exceptionsArray<String>

List of threat IDs to be excepted from generating alerts. Corresponds to the JSON property threatExceptions

Returns:

  • (Array<String>)


120
121
122
# File 'lib/google/apis/ids_v1/classes.rb', line 120

def threat_exceptions
  @threat_exceptions
end

#traffic_logsBoolean Also known as: traffic_logs?

Whether the endpoint should report traffic logs in addition to threat logs. Corresponds to the JSON property trafficLogs

Returns:

  • (Boolean)


125
126
127
# File 'lib/google/apis/ids_v1/classes.rb', line 125

def traffic_logs
  @traffic_logs
end

#update_timeString

Output only. The update time timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


131
132
133
# File 'lib/google/apis/ids_v1/classes.rb', line 131

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/google/apis/ids_v1/classes.rb', line 138

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @endpoint_forwarding_rule = args[:endpoint_forwarding_rule] if args.key?(:endpoint_forwarding_rule)
  @endpoint_ip = args[:endpoint_ip] if args.key?(:endpoint_ip)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @severity = args[:severity] if args.key?(:severity)
  @state = args[:state] if args.key?(:state)
  @threat_exceptions = args[:threat_exceptions] if args.key?(:threat_exceptions)
  @traffic_logs = args[:traffic_logs] if args.key?(:traffic_logs)
  @update_time = args[:update_time] if args.key?(:update_time)
end