Class: Google::Apis::IdsV1::ListLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::IdsV1::ListLocationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ids_v1/classes.rb,
lib/google/apis/ids_v1/representations.rb,
lib/google/apis/ids_v1/representations.rb
Overview
The response message for Locations.ListLocations.
Instance Attribute Summary collapse
-
#locations ⇒ Array<Google::Apis::IdsV1::Location>
A list of locations that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLocationsResponse
constructor
A new instance of ListLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLocationsResponse
Returns a new instance of ListLocationsResponse.
202 203 204 |
# File 'lib/google/apis/ids_v1/classes.rb', line 202 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Array<Google::Apis::IdsV1::Location>
A list of locations that matches the specified filter in the request.
Corresponds to the JSON property locations
195 196 197 |
# File 'lib/google/apis/ids_v1/classes.rb', line 195 def locations @locations end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
200 201 202 |
# File 'lib/google/apis/ids_v1/classes.rb', line 200 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
207 208 209 210 |
# File 'lib/google/apis/ids_v1/classes.rb', line 207 def update!(**args) @locations = args[:locations] if args.key?(:locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |