Class: Google::Apis::IdsV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/ids_v1/classes.rb,
lib/google/apis/ids_v1/representations.rb,
lib/google/apis/ids_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



399
400
401
# File 'lib/google/apis/ids_v1/classes.rb', line 399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


363
364
365
# File 'lib/google/apis/ids_v1/classes.rb', line 363

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


368
369
370
# File 'lib/google/apis/ids_v1/classes.rb', line 368

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


373
374
375
# File 'lib/google/apis/ids_v1/classes.rb', line 373

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


381
382
383
# File 'lib/google/apis/ids_v1/classes.rb', line 381

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


387
388
389
# File 'lib/google/apis/ids_v1/classes.rb', line 387

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


392
393
394
# File 'lib/google/apis/ids_v1/classes.rb', line 392

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


397
398
399
# File 'lib/google/apis/ids_v1/classes.rb', line 397

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



404
405
406
407
408
409
410
411
412
# File 'lib/google/apis/ids_v1/classes.rb', line 404

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end