Class: Google::Apis::IdsV1::IDSService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::IdsV1::IDSService
- Defined in:
- lib/google/apis/ids_v1/service.rb
Overview
Cloud IDS API
Cloud IDS (Cloud Intrusion Detection System) detects malware, spyware, command- and-control attacks, and other network-based threats. Its security efficacy is industry leading, built with Palo Alto Networks technologies. When you use this product, your organization name and consumption levels will be shared with Palo Alto Networks.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://ids.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_endpoint(parent, endpoint_object = nil, endpoint_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Operation
Creates a new Endpoint in a given project and location.
-
#delete_project_location_endpoint(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Operation
Deletes a single Endpoint.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Location
Gets information about a location.
-
#get_project_location_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Endpoint
Gets details of a single Endpoint.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ IDSService
constructor
A new instance of IDSService.
-
#list_project_location_endpoints(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::ListEndpointsResponse
Lists Endpoints in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_endpoint(name, endpoint_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Operation
Updates the parameters of a single Endpoint.
Constructor Details
#initialize ⇒ IDSService
Returns a new instance of IDSService.
51 52 53 54 55 56 |
# File 'lib/google/apis/ids_v1/service.rb', line 51 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-ids_v1', client_version: Google::Apis::IdsV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
44 45 46 |
# File 'lib/google/apis/ids_v1/service.rb', line 44 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
49 50 51 |
# File 'lib/google/apis/ids_v1/service.rb', line 49 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/google/apis/ids_v1/service.rb', line 395 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::IdsV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::IdsV1::Empty::Representation command.response_class = Google::Apis::IdsV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_endpoint(parent, endpoint_object = nil, endpoint_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Operation
Creates a new Endpoint in a given project and location.
181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/google/apis/ids_v1/service.rb', line 181 def create_project_location_endpoint(parent, endpoint_object = nil, endpoint_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/endpoints', ) command.request_representation = Google::Apis::IdsV1::Endpoint::Representation command.request_object = endpoint_object command.response_representation = Google::Apis::IdsV1::Operation::Representation command.response_class = Google::Apis::IdsV1::Operation command.params['parent'] = parent unless parent.nil? command.query['endpointId'] = endpoint_id unless endpoint_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_endpoint(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Operation
Deletes a single Endpoint.
226 227 228 229 230 231 232 233 234 235 |
# File 'lib/google/apis/ids_v1/service.rb', line 226 def delete_project_location_endpoint(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::IdsV1::Operation::Representation command.response_class = Google::Apis::IdsV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
430 431 432 433 434 435 436 437 438 |
# File 'lib/google/apis/ids_v1/service.rb', line 430 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::IdsV1::Empty::Representation command.response_class = Google::Apis::IdsV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Location
Gets information about a location.
78 79 80 81 82 83 84 85 86 |
# File 'lib/google/apis/ids_v1/service.rb', line 78 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::IdsV1::Location::Representation command.response_class = Google::Apis::IdsV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_endpoint(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Endpoint
Gets details of a single Endpoint.
258 259 260 261 262 263 264 265 266 |
# File 'lib/google/apis/ids_v1/service.rb', line 258 def get_project_location_endpoint(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::IdsV1::Endpoint::Representation command.response_class = Google::Apis::IdsV1::Endpoint command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
461 462 463 464 465 466 467 468 469 |
# File 'lib/google/apis/ids_v1/service.rb', line 461 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::IdsV1::Operation::Representation command.response_class = Google::Apis::IdsV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_endpoints(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::ListEndpointsResponse
Lists Endpoints in a given project and location.
301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/google/apis/ids_v1/service.rb', line 301 def list_project_location_endpoints(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/endpoints', ) command.response_representation = Google::Apis::IdsV1::ListEndpointsResponse::Representation command.response_class = Google::Apis::IdsV1::ListEndpointsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/google/apis/ids_v1/service.rb', line 506 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::IdsV1::ListOperationsResponse::Representation command.response_class = Google::Apis::IdsV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/google/apis/ids_v1/service.rb', line 130 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::IdsV1::ListLocationsResponse::Representation command.response_class = Google::Apis::IdsV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_endpoint(name, endpoint_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::IdsV1::Operation
Updates the parameters of a single Endpoint.
353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/google/apis/ids_v1/service.rb', line 353 def patch_project_location_endpoint(name, endpoint_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::IdsV1::Endpoint::Representation command.request_object = endpoint_object command.response_representation = Google::Apis::IdsV1::Operation::Representation command.response_class = Google::Apis::IdsV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |